Package: fuj
Type: Package
Title: Functions and Utilities for Jordan
Version: 0.2.1
Authors@R: 
    person(
      given = "Jordan Mark", 
      family = "Barbone",
      email = "jmbarbone@gmail.com",
      role = c("aut", "cph", "cre"),
      comment = c(ORCID = "0000-0001-9788-3628")
    )
Maintainer: Jordan Mark Barbone <jmbarbone@gmail.com>
Description: Provides core functions and utilities for packages and other code
    developed by Jordan Mark Barbone.
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.1
Depends: R (>= 3.6)
Suggests: spelling, testthat (>= 3.0.0)
Config/testthat/edition: 3
URL: https://jmbarbone.github.io/fuj/, https://github.com/jmbarbone/fuj
BugReports: https://github.com/jmbarbone/fuj/issues
NeedsCompilation: no
Packaged: 2024-05-20 13:59:00 UTC; jordan
Author: Jordan Mark Barbone [aut, cph, cre]
    (<https://orcid.org/0000-0001-9788-3628>)
Repository: CRAN
Date/Publication: 2024-05-20 14:20:03 UTC
Built: R 4.4.0; ; 2024-05-21 19:28:01 UTC; unix
