# Generated by roxygen2: do not edit by hand

S3method(conditionMessage,fujCondition)
S3method(flip,data.frame)
S3method(flip,default)
S3method(flip,matrix)
S3method(print,file_path)
export("%::%")
export("%:::%")
export("%attr%")
export("%colons%")
export("%len%")
export("%names%")
export("%out%")
export("%wi%")
export("%wo%")
export("%||%")
export("%|||%")
export(add)
export(any_match)
export(collapse)
export(divide)
export(divide_int)
export(empty_df)
export(exattr)
export(file_path)
export(flip)
export(fp)
export(include)
export(is_file_path)
export(is_in)
export(is_linux)
export(is_macos)
export(is_named)
export(is_out)
export(is_path)
export(is_windows)
export(is_within)
export(is_without)
export(list0)
export(lst)
export(make_verbose)
export(muffle)
export(multiply)
export(new_condition)
export(no_match)
export(op.fuj)
export(quick_df)
export(quick_dfl)
export(raise_power)
export(remainder)
export(remove_names)
export(require_namespace)
export(set_names)
export(struct)
export(subassign1)
export(subassign2)
export(subassign3)
export(subset1)
export(subset2)
export(subset3)
export(subtract)
export(verbose)
export(wuffle)
